# FileUpload

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**org_id** | **str** | Unique identifier | [optional] 
**tag** | **str** | A file tag | [optional] 
**label** | **str** | A file label | [optional] 
**region** | [**StorageRegion**](StorageRegion.md) |  | [optional] 
**name** | **str** | Name of file | 
**md5_hash** | **str** | MD5 Hash of file in base64 | [optional] 
**file_zip** | **file** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


